@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2023 DeepLime <contact@deeplime.io>
+# SPDX-FileCopyrightText: 2023-2024 DeepLime <contact@deeplime.io>
 # SPDX-License-Identifier: MIT
 
 from typing import Any
@@ -23,7 +23,7 @@ def is_type(
 
     """
     try:
-        check_type(value=obj, expected_type=t, argname='value')
+        check_type(value=obj, expected_type=t)
         return True
 
     except Exception:
